@@ -421,11 +421,11 @@ func configureContainer(
 	resourceRequests := make(map[corev1.ResourceName]k8sresource.Quantity)
 
 	if c.CPU != nil {
-		if c.CPU.Requested != "" {
-			q, err := k8sresource.ParseQuantity(c.CPU.Requested)
+		if c.CPU.Request != "" {
+			q, err := k8sresource.ParseQuantity(c.CPU.Request)
 			if err != nil {
 				return nil,
-					status.Errorf(codes.InvalidArgument, "failed to parse cpu request %s to k8s quantity: %s", c.CPU.Requested, err)
+					status.Errorf(codes.InvalidArgument, "failed to parse cpu request %s to k8s quantity: %s", c.CPU.Request, err)
 			}
 			resourceRequests[corev1.ResourceCPU] = q
 		}
@@ -441,11 +441,11 @@ func configureContainer(
 	}
 
 	if c.Memory != nil {
-		if c.Memory.Requested != "" {
-			q, err := k8sresource.ParseQuantity(c.Memory.Requested)
+		if c.Memory.Request != "" {
+			q, err := k8sresource.ParseQuantity(c.Memory.Request)
 			if err != nil {
 				return nil,
-					status.Errorf(codes.InvalidArgument, "failed to parse memory requested %s to k8s quantity: %s", c.Memory.Requested, err)
+					status.Errorf(codes.InvalidArgument, "failed to parse memory requested %s to k8s quantity: %s", c.Memory.Request, err)
 			}
 			resourceRequests[corev1.ResourceMemory] = q
 		}
@@ -640,6 +640,11 @@ func (p *Platform) resourceDeploymentCreate(
 	for k, v := range p.config.StaticEnvVars {
 		envVars[k] = v
 	}
+	if p.config.Pod != nil && p.config.Pod.Container != nil {
+		for k, v := range p.config.Pod.Container.StaticEnvVars {
+			envVars[k] = v
+		}
+	}
 	for k, v := range deployConfig.Env() {
 		envVars[k] = v
 	}
@@ -1470,8 +1475,8 @@ type Config struct {
 // ResourceConfig describes the request and limit of a resource. Used for
 // cpu and memory resource configuration.
 type ResourceConfig struct {
-	Requested string `hcl:"request,optional"`
-	Limit     string `hcl:"limit,optional"`
+	Request string `hcl:"request,optional" json:"request"`
+	Limit   string `hcl:"limit,optional" json:"limit"`
 }
 
 // AutoscaleConfig describes the possible configuration for creating a
@@ -1554,7 +1559,7 @@ func (p *Platform) Documentation() (*docs.Documentation, error) {
 	doc.Description("Deploy the application into a Kubernetes cluster using Deployment objects")
 
 	doc.Example(`
-deploy "kubernetes" {
+use "kubernetes" {
 	image_secret = "registry_secret"
 	replicas = 3
 	probe_path = "/_healthz"
@@ -1961,7 +1966,7 @@ deploy "kubernetes" {
 				}),
 			)
 			doc.SetField(
-				"pod_security_context",
+				"security_context",
 				"holds pod-level security attributes and container settings",
 				docs.SubFields(func(doc *docs.SubFieldDoc) {
 					doc.SetField(
