@@ -202,6 +202,10 @@ func (c *AppDocsCommand) emitField(w io.Writer, h, out string, f *docs.FieldDocs
 		}
 	}
 
+	if f.EnvVar != "" {
+		fmt.Fprintf(&list, "\n- Environment Variable: **%s**", f.EnvVar)
+	}
+
 	if list.Len() != 0 {
 		parts = append(parts, list.String())
 	}
@@ -233,15 +237,25 @@ func endingSpace(w io.Writer, i, tot int) {
 
 func splitFields(fields []*docs.FieldDocs) (required, optional []*docs.FieldDocs) {
 	var o, r []*docs.FieldDocs
-
+	// Categories and fields are both stored in FieldDocs, so if we see a category then check if any of its sub fields are not optional.
+	// If so, the whole category goes in the required section of the website docs, with the optional fields still being labelled as such
+	// within the category
 	for _, f := range fields {
-		if f.Optional {
-			o = append(o, f)
-		} else {
+		var requiredSubfield bool
+		if sf := f.SubFields; len(sf) > 0 {
+			for _, fo := range sf {
+				if !fo.Optional {
+					requiredSubfield = true
+					break
+				}
+			}
+		}
+		if requiredSubfield || (!f.Optional && !f.Category) {
 			r = append(r, f)
+		} else {
+			o = append(o, f)
 		}
 	}
-
 	return r, o
 }
 
