@@ -2,6 +2,7 @@ package cli
 
 import (
 	"context"
+	"strings"
 
 	empty "google.golang.org/protobuf/types/known/emptypb"
 
@@ -30,8 +31,21 @@ func (c *DestroyCommand) Run(args []string) int {
 
 	err := c.DoApp(c.Ctx, func(ctx context.Context, app *clientpkg.App) error {
 		if !c.confirm {
-			app.UI.Output("Destroying app %q requires confirmation with `-auto-approve`.", app.Ref().GetApplication(), terminal.WithWarningStyle())
-			return nil
+			proceed, err := c.ui.Input(&terminal.Input{
+				Prompt: "Do you really want to destroy all resources for this app? Only 'yes' will be accepted to approve: ",
+				Style:  "",
+				Secret: false,
+			})
+			if err != nil {
+				c.ui.Output(
+					"Error destroying resources: %s",
+					clierrors.Humanize(err),
+					terminal.WithErrorStyle(),
+				)
+			} else if strings.ToLower(proceed) != "yes" {
+				app.UI.Output("Destroying app %q requires confirmation.", app.Ref().GetApplication(), terminal.WithWarningStyle())
+				return nil
+			}
 		}
 
 		if err := app.Destroy(ctx, &pb.Job_DestroyOp{
@@ -64,7 +78,7 @@ func (c *DestroyCommand) Flags() *flag.Sets {
 			Name:    "auto-approve",
 			Target:  &c.confirm,
 			Default: false,
-			Usage:   "Confirm destroying all resources.",
+			Usage:   "Auto-approve destroying all resources. If unset, confirmation will be requested.",
 		})
 	})
 }
