@@ -3,19 +3,18 @@ package client
 import (
 	"context"
 
-	"github.com/golang/protobuf/ptypes/empty"
 	"github.com/hashicorp/go-hclog"
+	empty "google.golang.org/protobuf/types/known/emptypb"
 
 	configpkg "github.com/hashicorp/waypoint/internal/config"
 	"github.com/hashicorp/waypoint/internal/runner"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 // startRunner initializes and starts a local runner.
 // It stores it on the parent struct, and will deactivate it
 // when the parent is closed.
-func (c *Project) startRunner() error {
-
+func (c *Project) startRunner(ctx context.Context) error {
 	c.logger.Debug("starting runner to process local jobs")
 
 	// Initialize our runner
@@ -30,7 +29,7 @@ func (c *Project) startRunner() error {
 	}
 
 	// Start the runner
-	if err := r.Start(); err != nil {
+	if err := r.Start(ctx); err != nil {
 		return err
 	}
 
