@@ -9,8 +9,8 @@ import (
 	"github.com/mitchellh/copystructure"
 	"github.com/zclconf/go-cty/cty"
 
-	"github.com/hashicorp/waypoint/internal/config/funcs"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	"github.com/hashicorp/waypoint/pkg/config/funcs"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 // App represents a single application.
