@@ -40,7 +40,7 @@ func TestConfigValidate(t *testing.T) {
 			cfg, err := Load(filepath.Join("testdata", "validate", tt.File), nil)
 			require.NoError(err)
 
-			err = cfg.Validate()
+			_, err = cfg.Validate()
 			if tt.Err == "" {
 				require.NoError(err)
 				return
