@@ -9,8 +9,10 @@ import (
 	"github.com/hashicorp/waypoint/builtin/aws/ami"
 	"github.com/hashicorp/waypoint/builtin/aws/ec2"
 	"github.com/hashicorp/waypoint/builtin/aws/ecr"
+	awsecrpull "github.com/hashicorp/waypoint/builtin/aws/ecr/pull"
 	"github.com/hashicorp/waypoint/builtin/aws/ecs"
 	"github.com/hashicorp/waypoint/builtin/aws/lambda"
+	lambdaFunctionUrl "github.com/hashicorp/waypoint/builtin/aws/lambda/function_url"
 	"github.com/hashicorp/waypoint/builtin/aws/ssm"
 	"github.com/hashicorp/waypoint/builtin/azure/aci"
 	"github.com/hashicorp/waypoint/builtin/docker"
@@ -45,6 +47,7 @@ var (
 		"helm":                     k8shelm.Options,
 		"aws-ecs":                  ecs.Options,
 		"aws-ecr":                  ecr.Options,
+		"aws-ecr-pull":             awsecrpull.Options,
 		"nomad":                    nomad.Options,
 		"nomad-jobspec":            jobspec.Options,
 		"nomad-jobspec-canary":     jobspec.Options,
@@ -53,6 +56,7 @@ var (
 		"aws-alb":                  alb.Options,
 		"aws-ssm":                  ssm.Options,
 		"aws-lambda":               lambda.Options,
+		"lambda-function-url":      lambdaFunctionUrl.Options,
 		"vault":                    vault.Options,
 		"terraform-cloud":          tfc.Options,
 		"null":                     null.Options,
